@@ -1,10 +1,12 @@
 from django.conf import settings
 from django.db.models import signals
 
+
 def generate(app, created_models, verbosity, **kwargs):
     from django.core.management import call_command
     if kwargs.get('interactive', True):
-        msg = "\nInstallation complete. Do you want to genererate default content? (yes/no): "
+        msg = "\nInstallation complete. Do you want to genererate default \
+                content? (yes/no): "
         confirm = raw_input(msg)
         while 1:
             if confirm not in ('yes', 'no'):
@@ -14,14 +16,16 @@ def generate(app, created_models, verbosity, **kwargs):
                 call_command("generate", interactive=True)
             break
 
-# get last app with models
+# Get last app with models.
 last_app_with_models = None
 for app in settings.INSTALLED_APPS:
     try:
-        last_app_with_models = __import__("%s.models" % app, globals(), locals(), ['models', ], -1)
+        last_app_with_models = __import__("%s.models" % app, globals(), \
+                locals(), ['models', ], -1)
     except ImportError:
         pass
 
-# if we have a last app with models connect the post sync signal to generate content
+# If we have a last app with models connect the
+# post sync signal to generate content.
 if last_app_with_models:
     signals.post_syncdb.connect(generate, sender=last_app_with_models)
